@@ -24,6 +24,7 @@ CommentListModel::CommentListModel(QObject *parent) :
     m_error(false),
     m_offset(0)
 {
+#if QT_VERSION >= 0x040600
     QHash<int, QByteArray> roles;
     roles[IdRole] = "id";
     roles[BodyRole] = "body";
@@ -37,6 +38,7 @@ CommentListModel::CommentListModel(QObject *parent) :
     roles[AvatarPressedRole] = "avatarPressed";
 #endif
     this->setRoleNames(roles);
+#endif
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
 #endif
@@ -52,9 +54,9 @@ CommentListModel::~CommentListModel() {
 }
 
 void CommentListModel::clear() {
-    this->beginResetModel();
+    this->beginRemoveRows(QModelIndex(), 0, this->rowCount() - 1);
     m_list.clear();
-    this->endResetModel();
+    this->endRemoveRows();
     this->setLoading(false);
     this->setOffset(1);
     this->setMoreResults(true);
@@ -86,7 +88,7 @@ QVariant CommentListModel::data(const QModelIndex &index, int role) const {
         return m_list.at(index.row()).data()->artistId();
 #ifndef QML_USER_INTERFACE
     case ArtistAvatarRole:
-        return m_cache->thumbnail(m_list.at(index.row()).data()->artistAvatarUrl(), QSize(50, 50));
+        return m_cache->thumbnail(m_list.at(index.row()).data()->artistAvatarUrl(), QSize(48, 48));
     case AvatarPressedRole:
         return m_avatarPressedRow == index.row();
 #endif
@@ -101,9 +103,11 @@ QVariant CommentListModel::data(const QModelIndex &index, int role) const {
     }
 }
 
+#if QT_VERSION >= 0x040600
 QVariant CommentListModel::data(int row, const QByteArray &role) const {
     return this->data(this->index(row), this->roleNames().key(role));
 }
+#endif
 
 #ifndef QML_USER_INTERFACE
 bool CommentListModel::setData(const QModelIndex &index, const QVariant &value, int role) {
