@@ -14,6 +14,7 @@ ConnectionListModel::ConnectionListModel(QObject *parent) :
     m_loading(true),
     m_error(false)
 {
+#if QT_VERSION >= 0x040600
     QHash<int, QByteArray> roles;
     roles[IdRole] = "id";
     roles[DisplayNameRole] = "displayName";
@@ -21,6 +22,7 @@ ConnectionListModel::ConnectionListModel(QObject *parent) :
     roles[IconSourceRole] = "iconSource";
     roles[SelectedRole] = "selected";
     this->setRoleNames(roles);
+#endif
 }
 
 ConnectionListModel::~ConnectionListModel() {
@@ -28,9 +30,9 @@ ConnectionListModel::~ConnectionListModel() {
 }
 
 void ConnectionListModel::clear() {
-    this->beginResetModel();
+    this->beginRemoveRows(QModelIndex(), 0, this->rowCount() - 1);
     m_list.clear();
-    this->endResetModel();
+    this->endRemoveRows();
     this->setLoading(false);
     this->setError(false);
 }
@@ -65,9 +67,11 @@ QVariant ConnectionListModel::data(const QModelIndex &index, int role) const {
     }
 }
 
+#if QT_VERSION >= 0x040600
 QVariant ConnectionListModel::data(int row, const QByteArray &role) const {
     return this->data(this->index(row), this->roleNames().key(role));
 }
+#endif
 
 void ConnectionListModel::getConnections() {
     QNetworkReply *reply = SoundCloud::instance()->createReply(CONNECTIONS_FEED);
