@@ -15,6 +15,7 @@ class ConnectionListModel : public QAbstractListModel
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040700
     Q_PROPERTY(int count
                READ rowCount
                NOTIFY countChanged)
@@ -24,6 +25,7 @@ class ConnectionListModel : public QAbstractListModel
     Q_PROPERTY(bool itemsSelected
                READ itemsSelected
                NOTIFY itemsSelectedChanged)
+#endif
 
 public:
     enum Roles {
@@ -40,7 +42,9 @@ public:
     inline bool loading() const { return m_loading; }
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role) const;
+#if QT_VERSION >= 0x040600
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
+#endif
     Q_INVOKABLE QList<int> selectedRows() const { return m_selectedRows; }
     inline bool itemsSelected() const { return !this->selectedRows().isEmpty(); }
     Q_INVOKABLE QStringList connections() const;
