@@ -11,6 +11,7 @@
 #include <QUrl>
 #include <QDebug>
 #include <QThread>
+#include <QDesktopServices>
 
 Database* Database::m_instance = 0;
 
@@ -27,7 +28,7 @@ Database::Database() :
 
     this->moveToThread(m_thread);
     m_thread->start();
-#if (defined (Q_WS_MAEMO_5)) || (defined (MEEGO_EDITION_HARMATTAN))
+#if (defined (Q_WS_MAEMO_5)) || (defined (Q_WS_MAEMO_4)) || (defined (MEEGO_EDITION_HARMATTAN))
     QDir dir;
     dir.mkpath("/home/user/MusiKloud/");
     m_database.setDatabaseName("/home/user/MusiKloud/MusiKloud.sqlite");
@@ -438,11 +439,11 @@ QList< QSharedPointer<TrackItem> > Database::getStoredTrackDownloads() {
             track.data()->setGenre(query.value(4).toString());
             track.data()->setDuration(query.value(5).toInt());
             track.data()->setFormat(query.value(6).toString());
-            track.data()->setStreamUrl(query.value(7).toUrl());
+            track.data()->setStreamUrl(query.value(7).toString());
             track.data()->setDownloadable(query.value(8).toBool());
-            track.data()->setDownloadUrl(query.value(9).toUrl());
-            track.data()->setThumbnailUrl(query.value(10).toUrl());
-            track.data()->setWaveformUrl(query.value(11).toUrl());
+            track.data()->setDownloadUrl(query.value(9).toString());
+            track.data()->setThumbnailUrl(query.value(10).toString());
+            track.data()->setWaveformUrl(query.value(11).toString());
             track.data()->setPlaylistId(query.value(12).toString());
             track.data()->setTrackNumber(query.value(13).toInt());
             track.data()->setSize(query.value(14).toLongLong());
@@ -498,7 +499,7 @@ bool Database::addPlaylist(QSharedPointer<PlaylistItem> playlist) {
     query.addBindValue(playlist.data()->thumbnailUrl());
     query.addBindValue(playlist.data()->trackCount());
     query.addBindValue(playlist.data()->duration());
-    query.addBindValue(QDateTime::currentDateTime().toMSecsSinceEpoch());
+    query.addBindValue(Utils::currentMSecsSinceEpoch());
     success = query.exec();
     m_database.close();
 
@@ -529,7 +530,7 @@ QSharedPointer<PlaylistItem> Database::getPlaylist(const QString &id) {
             playlist.data()->setArtist(query.value(1).toString());
             playlist.data()->setTitle(query.value(2).toString());
             playlist.data()->setDescription(query.value(3).toString());
-            playlist.data()->setThumbnailUrl(query.value(4).toUrl());
+            playlist.data()->setThumbnailUrl(query.value(4).toString());
             playlist.data()->setTrackCount(query.value(5).toInt());
             playlist.data()->setDuration(query.value(6).toInt());
             playlist.data()->setDate(Utils::dateFromMSecs(query.value(7).toLongLong()));
@@ -580,7 +581,7 @@ bool Database::updatePlaylist(const QString &id, int trackCountChange, int durat
     query.prepare("UPDATE playlists SET trackCount = ?, duration = ?, lastModified = ? WHERE id = ?");
     query.addBindValue(newTrackCount);
     query.addBindValue(newDuration);
-    query.addBindValue(QDateTime::currentDateTime().toMSecsSinceEpoch());
+    query.addBindValue(Utils::currentMSecsSinceEpoch());
     query.addBindValue(id);
     success = query.exec();
     m_database.close();
@@ -653,7 +654,7 @@ bool Database::addTrack(QSharedPointer<TrackItem> track) {
     query.addBindValue(QVariant::Int);
     query.addBindValue(track.data()->size());
     query.addBindValue(track.data()->url().toString().section('.', -1));
-    query.addBindValue(QDateTime::currentDateTime().toMSecsSinceEpoch());
+    query.addBindValue(Utils::currentMSecsSinceEpoch());
     success = query.exec();
     m_database.close();
 
@@ -760,9 +761,9 @@ QList< QSharedPointer<TrackItem> > Database::getTracks(const QString &playlistId
             track.data()->setDescription(query.value(4).toString());
             track.data()->setGenre(query.value(5).toString());
             track.data()->setDuration(query.value(6).toInt());
-            track.data()->setThumbnailUrl(query.value(7).toUrl());
-            track.data()->setLargeThumbnailUrl(query.value(7).toUrl());
-            track.data()->setWaveformUrl(query.value(8).toUrl());
+            track.data()->setThumbnailUrl(query.value(7).toString());
+            track.data()->setLargeThumbnailUrl(query.value(7).toString());
+            track.data()->setWaveformUrl(query.value(8).toString());
             track.data()->setPlaylistId(query.value(9).toString());
             track.data()->setTrackNumber(query.value(10).toInt());
             track.data()->setPlayCount(query.value(11).toInt());
@@ -802,7 +803,7 @@ QList< QSharedPointer<PlaylistItem> > Database::getPlaylists() {
             playlist.data()->setArtist(query.value(1).toString());
             playlist.data()->setTitle(query.value(2).toString());
             playlist.data()->setDescription(query.value(3).toString());
-            playlist.data()->setThumbnailUrl(query.value(4).toUrl());
+            playlist.data()->setThumbnailUrl(query.value(4).toString());
             playlist.data()->setTrackCount(query.value(5).toInt());
             playlist.data()->setDuration(query.value(6).toInt());
             playlist.data()->setDate(Utils::dateFromMSecs(query.value(7).toLongLong()));
