@@ -3,11 +3,13 @@
 ExploreModel::ExploreModel(QObject *parent) :
     QAbstractListModel(parent)
 {
+#if QT_VERSION >= 0x040600
     QHash<int, QByteArray> roles;
     roles[NameRole] = "name";
     roles[TypeRole] = "type";
     roles[FeedRole] = "feed";
     this->setRoleNames(roles);
+#endif
 
     this->addItem(Queries::Tracks, QUrl("http://api.soundcloud.com/tracks.json?limit=30&order=created_at&filter=public,streamable"), tr("Latest tracks"));
     this->addItem(Queries::Tracks, QUrl("http://api.soundcloud.com/tracks.json?limit=30&order=hotness&filter=public,streamable"), tr("Hottest tracks"));
@@ -36,9 +38,11 @@ QVariant ExploreModel::data(const QModelIndex &index, int role) const {
     }
 }
 
+#if QT_VERSION >= 0x040600
 QVariant ExploreModel::data(int row, const QByteArray &role) const {
     return this->data(this->index(row), this->roleNames().key(role));
 }
+#endif
 
 void ExploreModel::addItem(Queries::QueryType type, const QUrl &feed, const QString &name) {
     ExploreItem item;
