@@ -16,9 +16,11 @@ class ExploreModel : public QAbstractListModel
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040700
     Q_PROPERTY(int count
                READ rowCount
                NOTIFY countChanged)
+#endif
 
 public:
     enum Roles {
@@ -32,7 +34,9 @@ public:
     explicit ExploreModel(QObject *parent = 0);
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role) const;
+#if QT_VERSION >= 0x040600
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
+#endif
 
 private:
     void addItem(Queries::QueryType type, const QUrl &feed, const QString &name);
