@@ -4,17 +4,25 @@
 HomescreenModel::HomescreenModel(QObject *parent) :
     QAbstractListModel(parent)
 {
+#if QT_VERSION >= 0x040600
     QHash<int, QByteArray> roles;
     roles[NameRole] = "name";
     roles[IconSourceRole] = "iconSource";
     this->setRoleNames(roles);
+#endif
 
+#ifdef Q_WS_MAEMO_4
+    m_list.append(QPair<QString, QString>(tr("You"), "/usr/share/icons/hicolor/64x64/hildon/qgn_addr_icon_avatar.png"));
+    m_list.append(QPair<QString, QString>(tr("Dashboard"), "/usr/share/icons/hicolor/scalable/hildon/qgn_list_rss.png"));
+    m_list.append(QPair<QString, QString>(tr("Explore"), "/usr/share/icons/hicolor/scalable/hildon/qgn_grid_tasknavigator_web.png"));
+    m_list.append(QPair<QString, QString>(tr("Archive"), "/usr/share/icons/hicolor/scalable/hildon/qgn_list_filesys_audio_fldr.png"));
+#else
     m_list.append(QPair<QString, QString>(tr("You"), "images/you.png"));
     m_list.append(QPair<QString, QString>(tr("Dashboard"), "images/dashboard.png"));
     m_list.append(QPair<QString, QString>(tr("Explore"), "images/explore.png"));
     m_list.append(QPair<QString, QString>(tr("Search"), "images/search.png"));
     m_list.append(QPair<QString, QString>(tr("Queue"), "images/queue.png"));
-#ifndef MEEGO_EDITION_HARMATTAN
+#if !defined (MEEGO_EDITION_HARMATTAN)
     m_list.append(QPair<QString, QString>(tr("Transfers"), "images/transfers.png"));
 #endif
     m_list.append(QPair<QString, QString>(tr("Archive"), "images/archive.png"));
@@ -23,6 +31,7 @@ HomescreenModel::HomescreenModel(QObject *parent) :
 #ifdef MEEGO_EDITION_HARMATTAN
     m_list.append(QPair<QString, QString>(tr("About"), "images/about.png"));
 #endif
+#endif
 }
 
 int HomescreenModel::rowCount(const QModelIndex &parent) const {
@@ -42,6 +51,8 @@ QVariant HomescreenModel::data(const QModelIndex &index, int role) const {
     }
 }
 
+#if QT_VERSION >= 0x040600
 QVariant HomescreenModel::data(int row, const QByteArray &role) const {
     return this->data(this->index(row), this->roleNames().key(role));
 }
+#endif
