@@ -19,7 +19,9 @@ public:
     explicit HomescreenModel(QObject *parent = 0);
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role) const;
+#if QT_VERSION >= 0x040600
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
+#endif
     
 private:
     QList< QPair<QString, QString> > m_list;
