@@ -13,12 +13,14 @@ class Lastfm : public QObject
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040700
     Q_PROPERTY(QString username
                READ username
                NOTIFY usernameChanged)
     Q_PROPERTY(bool userSignedIn
                READ userSignedIn
                NOTIFY userSignedInChanged)
+#endif
 
 public:
     explicit Lastfm(QObject *parent = 0);
