@@ -3,7 +3,7 @@
 
 #include <QObject>
 
-#ifndef QML_USER_INTERFACE
+#if (!defined (QML_USER_INTERFACE)) && (defined (Q_WS_MAEMO_5))
 class QProgressDialog;
 #endif
 
@@ -13,11 +13,13 @@ class Notifications : public QObject
 
 public:
     explicit Notifications(QObject *parent = 0);
-#ifdef Q_WS_MAEMO_5
+#if (defined (Q_WS_MAEMO_5) || (defined (Q_WS_MAEMO_4)))
     static void showAlert(const QString &message);
     static void showInfo(const QString &message);
     static void showError(const QString &message);
+#ifdef Q_WS_MAEMO_5
     static void toggleBusy(bool busy);
+#endif
 #endif
     static Notifications* instance();
         
@@ -27,7 +29,7 @@ public slots:
     void onError(const QString &message);
     void showProgressDialog(const QString &message, int numberOfOperations);
     void updateProgressDialog(int progress);
-#ifndef QML_USER_INTERFACE
+#if (!defined (QML_USER_INTERFACE)) && (defined (Q_WS_MAEMO_5))
     void cancelProgressDialog();
 #endif
 
@@ -40,7 +42,7 @@ signals:
 
 private:
     static Notifications* m_instance;
-#ifndef QML_USER_INTERFACE
+#if (!defined (QML_USER_INTERFACE)) && (defined (Q_WS_MAEMO_5))
     QProgressDialog *m_progressDialog;
 #endif
 };
