@@ -13,12 +13,14 @@ class PlaybackListModel : public QAbstractListModel
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040700
     Q_PROPERTY(int count
                READ rowCount
                NOTIFY countChanged)
     Q_PROPERTY(bool itemsSelected
                READ itemsSelected
                NOTIFY itemsSelectedChanged)
+#endif
 
 public:
     enum Roles {
@@ -28,6 +30,7 @@ public:
         ArtistRole,
         DateRole,
         DurationRole,
+        UrlRole,
         StreamUrlRole,
 #ifndef QML_USER_INTERFACE
         ThumbnailRole,
@@ -50,7 +53,9 @@ public:
 #endif
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role) const;
+#if QT_VERSION >= 0x040600
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
+#endif
 #ifndef QML_USER_INTERFACE
     bool setData(const QModelIndex &index, const QVariant &value, int role);
 #endif
