@@ -644,7 +644,11 @@ void SoundCloud::putRequest(const QUrl &url) {
 void SoundCloud::deleteRequest(const QUrl &url) {
     qDebug() << url;
     QNetworkRequest request(url);
+#if QT_VERSION >= 0x040600
     QNetworkReply *reply = this->networkAccessManager()->deleteResource(request);
+#else
+    QNetworkReply *reply = this->networkAccessManager()->post(request, "");
+#endif
     this->connect(reply, SIGNAL(finished()), this, SLOT(postFinished()));
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
 }
