@@ -15,20 +15,20 @@
 #include <contentaction/contentaction.h>
 #endif
 
-TrackLauncher::TrackLauncher* launcherInstance = 0;
+TrackLauncher* TrackLauncher::m_instance = 0;
 
 TrackLauncher::TrackLauncher(QObject *parent) :
     QObject(parent)
 {
-    if (!launcherInstance) {
-        launcherInstance = this;
+    if (!m_instance) {
+        m_instance = this;
     }
 }
 
 TrackLauncher::~TrackLauncher() {}
 
 TrackLauncher* TrackLauncher::instance() {
-    return launcherInstance;
+    return !m_instance ? new TrackLauncher : m_instance;
 }
 
 void TrackLauncher::launchTrack(const QUrl &url) {
