@@ -26,6 +26,7 @@ TrackListModel::TrackListModel(QObject * parent) :
     m_offset(0),
     m_refresh(false)
 {
+#if QT_VERSION >= 0x040600
     QHash<int, QByteArray> roles;
     roles[IdRole] = "id";
     roles[PlaylistIdRole] = "playlistId";
@@ -44,6 +45,7 @@ TrackListModel::TrackListModel(QObject * parent) :
     roles[FavouriteRole] = "favourite";
     roles[SelectedRole] = "selected";
     this->setRoleNames(roles);
+#endif
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
 #endif
@@ -58,9 +60,9 @@ TrackListModel::~TrackListModel() {
 }
 
 void TrackListModel::clear() {
-    this->beginResetModel();
+    this->beginRemoveRows(QModelIndex(), 0, this->rowCount() - 1);
     m_list.clear();
-    this->endResetModel();
+    this->endRemoveRows();
     this->setLoading(false);
     this->setOffset(1);
     this->setMoreResults(true);
@@ -118,9 +120,11 @@ QVariant TrackListModel::data(const QModelIndex &index, int role) const {
     }
 }
 
+#if QT_VERSION >= 0x040600
 QVariant TrackListModel::data(int row, const QByteArray &role) const {
     return this->data(this->index(row), this->roleNames().key(role));
 }
+#endif
 
 #ifndef QML_USER_INTERFACE
 bool TrackListModel::setData(const QModelIndex &index, const QVariant &value, int role) {
