@@ -44,7 +44,7 @@ UserItem::UserItem(const QVariantMap &user, bool followed, QObject *parent) :
     m_id(user.value("id").toString()),
     m_username(user.value("username").toString()),
     m_description(user.value("description").toString().remove('\r')),
-    m_avatarUrl(user.value("avatar_url").toUrl()),
+    m_avatarUrl(user.value("avatar_url").toString()),
     m_fullname(user.value("full_name").toString()),
     m_bandname(user.value("discogs_name").toString()),
     m_city(user.value("city").toString()),
@@ -54,7 +54,7 @@ UserItem::UserItem(const QVariantMap &user, bool followed, QObject *parent) :
     m_favouritesCount(user.value("public_favorites_count").toInt()),
     m_followersCount(user.value("followers_count").toInt()),
     m_followingsCount(user.value("followings_count").toInt()),
-    m_websiteUrl(user.value("website").toUrl()),
+    m_websiteUrl(user.value("website").toString()),
     m_website(user.value("website_title").toString()),
     m_followed(followed),
     m_online(user.value("online").toBool()),
@@ -95,7 +95,7 @@ void UserItem::onProfileUpdated(const QString &id, const QVariantMap &profile) {
         this->setDescription(profile.value("description").toString().remove('\r'));
         this->setFullname(profile.value("full_name").toString());
         this->setBandname(profile.value("discogs_name").toString());
-        this->setWebsiteUrl(profile.value("website").toUrl());
+        this->setWebsiteUrl(profile.value("website").toString());
         this->setWebsiteTitle(profile.value("website_title").toString());
     }
 }
