@@ -11,6 +11,7 @@ class UserItem : public QObject
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040700
     Q_PROPERTY(QString id
                READ id
                NOTIFY idChanged)
@@ -72,6 +73,7 @@ class UserItem : public QObject
     Q_PROPERTY(Services::AudioService service
                READ service
                NOTIFY serviceChanged)
+#endif
 
 public:
     explicit UserItem(QObject *parent = 0);
