@@ -24,6 +24,7 @@ UserListModel::UserListModel(QObject *parent) :
     m_offset(0),
     m_refresh(false)
 {
+#if QT_VERSION >= 0x040600
     QHash<int, QByteArray> roles;
     roles[IdRole] = "id";
     roles[UsernameRole] = "username";
@@ -34,6 +35,7 @@ UserListModel::UserListModel(QObject *parent) :
     roles[TrackCountRole] = "trackCount";
     roles[PlaylistCountRole] = "playlistCount";
     this->setRoleNames(roles);
+#endif
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
 #endif
@@ -48,9 +50,9 @@ UserListModel::~UserListModel() {
 }
 
 void UserListModel::clear() {
-    this->beginResetModel();
+    this->beginRemoveRows(QModelIndex(), 0, this->rowCount() - 1);
     m_list.clear();
-    this->endResetModel();
+    this->endRemoveRows();
     this->setLoading(false);
     this->setOffset(1);
     this->setMoreResults(true);
@@ -92,9 +94,11 @@ QVariant UserListModel::data(const QModelIndex &index, int role) const {
     }
 }
 
+#if QT_VERSION >= 0x040600
 QVariant UserListModel::data(int row, const QByteArray &role) const {
     return this->data(this->index(row), this->roleNames().key(role));
 }
+#endif
 
 QSharedPointer<UserItem> UserListModel::get(int row) const {
     if ((row >= 0) && (row < m_list.size())) {
