@@ -2,7 +2,7 @@
 #include "../base/activitylistmodel.h"
 #include "../base/feedurls.h"
 #include "../base/soundcloud.h"
-#include "../base/mediaplayer.h"
+#include "../mediaplayer/mobility/mediaplayer.h"
 #include "../base/settings.h"
 #include "../base/tracklauncher.h"
 #include "listview.h"
