@@ -6,7 +6,9 @@
 #include "archiveplaylisttrackswindow.h"
 #include "../base/playlistlistmodel.h"
 #include "../base/archiveplaylistmodel.h"
-#include "../base/windowstack.h"
+#include "../base/settings.h"
+#include "windowstack.h"
+#include "nowplayingbutton.h"
 #include <QLabel>
 #include <QMenu>
 #include <QAction>
@@ -30,6 +32,7 @@ ArchivePlaylistsTab::ArchivePlaylistsTab(QWidget *parent) :
     m_noResultsLabel->hide();
     m_view->setModel(m_model);
     m_view->setItemDelegate(new ArchivePlaylistDelegate(m_view));
+    m_view->setMonitorScrolling(true);
 
     this->connect(m_model, SIGNAL(countChanged(int)), this, SLOT(onCountChanged(int)));
     this->connect(m_view, SIGNAL(clicked(QModelIndex)), this, SLOT(onItemClicked(QModelIndex)));
@@ -37,6 +40,11 @@ ArchivePlaylistsTab::ArchivePlaylistsTab(QWidget *parent) :
     this->connect(m_filterBox, SIGNAL(cleared()), m_filterBox, SLOT(hide()));
     this->connect(m_filterBox, SIGNAL(filterTextChanged(QString)), m_model, SLOT(setQuery(QString)));
 
+    if (Settings::instance()->mediaPlayer() == "musikloud") {
+        this->connect(m_view, SIGNAL(scrollingStarted()), NowPlayingButton::instance(), SLOT(hide()));
+        this->connect(m_view, SIGNAL(scrollingStopped()), NowPlayingButton::instance(), SLOT(poke()));
+    }
+
     m_model->getPlaylists();
     this->onOrientationChanged();
 }
