@@ -1,5 +1,5 @@
 #include "mediaplayerbutton.h"
-#include "../base/mediaplayer.h"
+#include "../mediaplayer/mobility/mediaplayer.h"
 #include <QPainter>
 #include <QPaintEvent>
 #include <QMaemo5Style>
