@@ -1,7 +1,7 @@
 #ifndef NOWPLAYINGBUTTON_H
 #define NOWPLAYINGBUTTON_H
 
-#include "../base/mediaplayer.h"
+#include "../mediaplayer/mobility/mediaplayer.h"
 #include <QWidget>
 
 class StackedWindow;
