@@ -1,12 +1,14 @@
 #include "profiletab.h"
+#include "scrollarea.h"
+#include "nowplayingbutton.h"
 #include "../base/soundcloud.h"
 #include "../base/notifications.h"
 #include "../base/thumbnailcache.h"
+#include "../base/settings.h"
 #include "separatorlabel.h"
 #include "avatarlabel.h"
 #include <QLabel>
 #include <QPushButton>
-#include <QScrollArea>
 #include <QGridLayout>
 #include <QMaemo5Style>
 
@@ -24,7 +26,7 @@ ProfileTab::ProfileTab(const QString &userId, QWidget *parent) :
     m_descriptionLabel(new QLabel(this)),
     m_noProfileLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No profile found")), this)),
     m_followingButton(new QPushButton(tr("Follow"))),
-    m_scrollArea(new QScrollArea(this)),
+    m_scrollArea(new ScrollArea(this)),
     m_grid(new QGridLayout(this))
 {
     QWidget *scrollWidget = new QWidget(m_scrollArea);
@@ -49,6 +51,7 @@ ProfileTab::ProfileTab(const QString &userId, QWidget *parent) :
     m_scrollArea->setWidgetResizable(true);
     m_scrollArea->setWidget(scrollWidget);
     m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_scrollArea->setMonitorScrolling(true);
     m_descriptionLabel->setWordWrap(true);
     m_scrollArea->hide();
     m_noProfileLabel->hide();
@@ -60,6 +63,11 @@ ProfileTab::ProfileTab(const QString &userId, QWidget *parent) :
     this->connect(SoundCloud::instance(), SIGNAL(error(QString)), this, SLOT(onProfileError()));
     this->connect(m_followingButton, SIGNAL(clicked()), this, SLOT(toggleFollowing()));
 
+    if (Settings::instance()->mediaPlayer() == "musikloud") {
+        this->connect(m_scrollArea, SIGNAL(scrollingStarted()), NowPlayingButton::instance(), SLOT(hide()));
+        this->connect(m_scrollArea, SIGNAL(scrollingStopped()), NowPlayingButton::instance(), SLOT(poke()));
+    }
+
     if ((userId == "me") || (userId == SoundCloud::instance()->username())) {
         SoundCloud::instance()->getCurrentUserProfile();
         m_followingButton->hide();
@@ -86,7 +94,7 @@ ProfileTab::ProfileTab(QSharedPointer<UserItem> user, QWidget *parent) :
     m_descriptionLabel(new QLabel(this)),
     m_noProfileLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No profile found")), this)),
     m_followingButton(new QPushButton(tr("Follow"))),
-    m_scrollArea(new QScrollArea(this)),
+    m_scrollArea(new ScrollArea(this)),
     m_grid(new QGridLayout(this))
 {
     QWidget *scrollWidget = new QWidget(m_scrollArea);
@@ -111,6 +119,7 @@ ProfileTab::ProfileTab(QSharedPointer<UserItem> user, QWidget *parent) :
     m_scrollArea->setWidgetResizable(true);
     m_scrollArea->setWidget(scrollWidget);
     m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_scrollArea->setMonitorScrolling(true);
     m_descriptionLabel->setWordWrap(true);
     m_scrollArea->hide();
     m_noProfileLabel->hide();
@@ -120,6 +129,11 @@ ProfileTab::ProfileTab(QSharedPointer<UserItem> user, QWidget *parent) :
 
     this->connect(m_followingButton, SIGNAL(clicked()), this, SLOT(toggleFollowing()));
 
+    if (Settings::instance()->mediaPlayer() == "musikloud") {
+        this->connect(m_scrollArea, SIGNAL(scrollingStarted()), NowPlayingButton::instance(), SLOT(hide()));
+        this->connect(m_scrollArea, SIGNAL(scrollingStopped()), NowPlayingButton::instance(), SLOT(poke()));
+    }
+
     if ((user.data()->id() == "me") || (user.data()->id() == SoundCloud::instance()->username())) {
         m_followingButton->hide();
     }
