@@ -8,10 +8,8 @@ class DownloadFormatSelector;
 class ConcurrentTransfersSelector;
 class ScreenOrientationSelector;
 class LanguageSelector;
-class NetworkProxyDialog;
 class QCheckBox;
 class QLineEdit;
-class QPushButton;
 class QScrollArea;
 class QDialogButtonBox;
 class QGridLayout;
@@ -27,7 +25,6 @@ public:
 private slots:
     void saveSettings();
     void showFileDialog();
-    void showNetworkProxyDialog();
     void onMediaPlayerChanged(const QString &player);
 
 private:
@@ -44,7 +41,6 @@ private:
     QCheckBox *m_transferStatusCheckbox;
     QCheckBox *m_eventFeedCheckbox;
     QCheckBox *m_clipboardCheckbox;
-    QPushButton *m_proxyButton;
     QMaemo5ValueButton *m_downloadFolderSelector;
     QString m_downloadPath;
     MediaPlayerSelector *m_mediaPlayerSelector;
@@ -55,7 +51,6 @@ private:
     QLineEdit *m_mediaPlayerCommandEdit;
     QDialogButtonBox *m_buttonBox;
     QScrollArea *m_scrollArea;
-    NetworkProxyDialog *m_proxyDialog;
     QGridLayout *m_grid;
     bool m_eventFeedEnabled;
 };
