@@ -13,7 +13,7 @@
 #include "../base/notifications.h"
 #include "../base/tracklistmodel.h"
 #include "../base/tracklauncher.h"
-#include "../base/mediaplayer.h"
+#include "../mediaplayer/mobility/mediaplayer.h"
 #include <QAction>
 #include <QLabel>
 #include <QGridLayout>
